# This is a very basic example of using libgretl with Python
# Adapted from Gretl API, Data I-O example
# Example for GNU/Linux

# ctypes module is the one that allows to load *.dll, or *.so libraries
from ctypes import *

# seems that in Linux we must use absolute path
libgretl = CDLL("/usr/local/lib/libgretl-1.0.so")

# now we can init libgretl
libgretl.libgretl_init()

# to be easily comparable with C example, here are some definitions
# this one comes from gretl_prn.h (first element of enum)
GRETL_PRINT_STDOUT = 0
# C to Python
NULL = None

# this should have been an argument, but for now is static example
fname = '/usr/local/share/gretl/data/data9-1.gdt'

prn = libgretl.gretl_print_new(GRETL_PRINT_STDOUT, NULL)

dset = libgretl.datainfo_new()

err = libgretl.gretl_read_native_data( fname, dset)

if err is not 0:
    libgretl.pprintf(prn, "Got error %d reading data from %s\n", err, fname)
    libgretl.errmsg(err, prn)
else:
    libgretl.pprintf(prn, "Read data from %s OK\n", fname)
    libgretl.print_smpl(dset, 0, prn)
    libgretl.varlist(dset, prn)


libgretl.destroy_dataset(dset)
libgretl.gretl_print_destroy(prn)
libgretl.libgretl_cleanup()
